#!/usr/bin/python
#
#  Copyright (c) 1998, Sean Reifschneider, tummy.com, ltd.  
#	All Rights Reserved.
#
#  Module which generates HTML-format reports.  Is called by the generator.py
#  module *ONLY*.  Requires only being imported by the "stdreport" program,
#  it automatically registers with the generator to generate reports.
#
#  http://www.tummy.com/radiusContext/
#  ftp://ftp.tummy.com/pub/tummy/radiusContext/

import time
import generator
from radiussupp import *

class genhtml:
	genname = "HTML"

	def __init__(self):
		self.out = None
		self.outIndex = None
		self.reportDirName = "."
		self.reportIndexName = "index"
		self.reportSuffix = ".html"
		self.splitTableAt = 100
		self.indexRow = 0

	def reportDir(self, name):
		self.reportDirName = name

	def reportIndex(self, name):
		self.reportIndexName = name

	def Start(self, sesData):
		self.out = open(self.reportDirName + "/" + sesData["userName"]
				+ self.reportSuffix, "w")
		title = "Session report for: %s\n" % ( sesData["userName"] )
		self.out.write("<HTML>\n<HEAD>\n<TITLE>" + title + "</TITLE>\n</HEAD>\n")
		self.out.write("<BODY><H1>" + title + "</H1>\n")
		self.out.write("<TABLE BORDER=1>\n")
		self.out.write("<TR><TH>Login Date</TH><TH>Time<BR>This</TH>")
		self.out.write("<TH>Time<BR>Total</TH>")
		self.out.write("<TH>BW<BR>In/Out</TH><TH>Reason</TH></TR>\n")

	def Stop(self, sesData):
		if self.out != None:
			self.out.write("</TABLE>\n")
			self.out.write("<TABLE BORDER=1>\n")
			self.out.write("<TR><TD>Total Online Time:</TD><TD>%s</TD></TR>" %
					( secsToStr(sesData["timeOn"]) ))
			self.out.write("<TR><TD>Days on:</TD><TD>%d</TD></TR>\n"
					% ( sesData["numDays"] ))
			self.out.write("<TR><TD>Average Online Times:</TD><TD>%s per day"
					% ( secsToStr(sesData["timeOn"] / sesData["numDays"]) ))
			self.out.write("</TD><TD>%s per session</TD></TR>\n" %
					(secsToStr(sesData["timeOn"] / sesData["sessionCount"]) ))

			self.out.write("<TR><TD>Total Data Transferred In/Out:</TD>")
			self.out.write("<TD>%s/%s</TD></TR>\n" %
					( bytesToStr(sesData["bytesIn"]),
					bytesToStr(sesData["bytesOut"]) ))
			self.out.write("<TR><TD>Rate In/Out:</TD><TD>%s/%s</TD>\n" %
					( sesData["bwIn"], sesData["bwOut"] ))
			self.out.write("</TABLE>\n")
			self.out.write("\n<P>Generated by <A HREF=\"http://www.tummy.com/" +
					"radiusContext/\">radiusContext</A>\n")
			self.out.write("</BODY></HTML>\n")
			self.out.close()
			self.out = None

	def Item(self, userData, sesData):
		termReason = sesData.get("Acct-Terminate-Cause", "")
		if termReason == "User-Request":
			termReason = ""

		self.out.write("<TR><TD>%-23s</TD><TD>%8s</TD><TD>%8s</TD>" %
				( sesData["Session-Start-Date"],
				secsToStr(sesData["currentTime"], 2),
				secsToStr(userData["timeOn"], 2) ))
		self.out.write("<TD>%6s/%-6s</TD><TD>%s</TD></TR>\n" %
				( sesData["bwIn"],
				sesData["bwOut"],
				termReason ))

	def IndexStart(self):
		self.outIndex = open(self.reportDirName + "/" + self.reportIndexName
				+ self.reportSuffix, "w")
		title = "Overall Dial-In Report generated %s" % (
				time.strftime("%A, %B %d, %Y", time.localtime(time.time())) )
		self.outIndex.write("<HTML>\n<HEAD>\n<TITLE>" + title
				+ "</TITLE>\n</HEAD>\n")
		self.outIndex.write("<BODY><H1>" + title + "</H1>\n")

		self.IndexTableStart()

	def IndexTableStart(self):
		self.outIndex.write("<TABLE BORDER=1>\n")
		self.outIndex.write("<TR><TH>User Name</TH><TH>Session<BR>Count</TH><TH>")
		self.outIndex.write("Time<BR>Total</TH><TH>Time<BR>Per Day</TH><TH>")
		self.outIndex.write("Time<BR>Per Ses</TH><TH>BW<BR>In/Out</TH></TR>\n")

	def IndexTableStop(self):
		self.outIndex.write("</TABLE>\n")

	def IndexStop(self, indexData):
		if self.outIndex != None:
			self.IndexTableStop()
			self.outIndex.write("<TABLE BORDER=1>\n")

			self.outIndex.write(
					"<TR><TD>Average Online Time:</TD><TD></TD><TD>%s per user" %
					( secsToStr(indexData["timePerUser"]) ))
			self.outIndex.write("</TD><TD>%s per session</TD></TR>\n" %
					( secsToStr(indexData["timePerSes"]) ))
			self.outIndex.write("<TR><TD>Average Sessions:</TD><TD></TD>")
			self.outIndex.write("<TD>%d per user</TD></TR>\n" %
					( indexData["sesPerUser"] ))
			self.outIndex.write("<TR><TD>Data In/Out:</TD><TD>%s/%s total</TD>" %
					( bytesToStr(indexData["bytesIn"]),
					bytesToStr(indexData["bytesOut"]) ))
			self.outIndex.write("<TD>%s/%s per user</TD>" %
					( bytesToStr(indexData["dataInPerUser"]),
					bytesToStr(indexData["dataOutPerUser"]) ))
			self.outIndex.write("<TD>%s/%s per session</TD></TR>\n" %
					( bytesToStr(indexData["dataInPerSes"]),
					bytesToStr(indexData["dataOutPerSes"]) ))

			self.outIndex.write("<TR><TD>Throughput In/Out:</TD>")
			self.outIndex.write("<TD>%s/%s total</TD>" %
					( bytesToStr(indexData["bwIn"]),
					bytesToStr(indexData["bwOut"]) ))
			self.outIndex.write("<TD>%s/%s per user</TD></TR>\n" %
					( bytesToStr(indexData["bwInUser"]),
					bytesToStr(indexData["bwOutUser"]) ))
			self.outIndex.write("</TABLE>\n")
			self.outIndex.write("\n<P>Generated by " +
					"<A HREF=\"http://www.tummy.com/radiusContext/\">" +
					"radiusContext</A>\n")
			self.outIndex.write("</BODY></HTML>\n")
			self.outIndex.close()
			self.outIndex = None

	def IndexItem(self, indexData, userData):
		if self.splitTableAt > 0 and self.indexRow > self.splitTableAt:
			self.IndexTableStop()
			self.IndexTableStart()
			self.indexRow = 0
		self.indexRow = self.indexRow + 1

		self.outIndex.write("<TR><TD><A HREF=\"" + userData["userName"]
				+ self.reportSuffix + "\">%s</TD><TD>%d</TD><TD>%s</TD><TD>" %
				( userData["userName"], userData["sessionCount"],
				secsToStr(userData["timeOn"], 2) ))
		self.outIndex.write("%s</TD><TD>%s</TD><TD>%s/%s</TD><TD></TR>\n" %
				( secsToStr(userData["timeOn"] / userData["numDays"], 2),
				secsToStr(userData["timeOn"] / userData["sessionCount"], 2),
				bytesToStr(userData["bytesIn"]),
				bytesToStr(userData["bytesOut"]) ))
		self.outIndex.flush()

generator.append(genhtml())
